/*	$NetBSD$	*/

/*-
 * Copyright (c) 2009 SHIMIZU Ryo <ryo@nerv.org>
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING
 * IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _STARREG_H_
#define _STARREG_H_

/*
 * Reference:
 *   - Equuleus Series: STR813X/CNS213X, STR818X/CNS218X Network Access Processor DataSheet
 *     http://www.cnusers.org/index.php?option=com_remository&Itemid=32&func=fileinfo&id=96
 *
 *   - Orion Series: STR91XX/CNS11XX Broadband Home Gateway Processor Data Sheet
 *     http://www.cnusers.org/index.php?option=com_remository&Itemid=32&func=fileinfo&id=77
 */

/*
 * Physical/Virtual memory map for the STR8100/STR9100
 *
 * Physical Virtual  STR8100                     STR9100
 * -------- -------- --------------------------- ---------------------------
 * 00000000          Alias Memory                Alias Memory
 * 10000000 F1000000 Flash/SRAM Memory           Flash/SRAM Memory
 * 18000000 F1800000 IDE Device Reg              reserved
 * 20000000          SDR/DDR SDRAM Memory        SDR/DDR SDRAM Memory
 * 30000000 F3000000 SPI Serial Flash Memory     SPI Serial Flash Memory
 * 40000000 F4000000 -                           DDR SDRAM Control Reg
 * 60000000 F6000000 Generic DMA                 Generic DMA
 * 70000000 F7000000 NIC                         Switch and HWNAT
 * 71000000 F7100000 SPI/PCM/TWI/IS              -
 * 72000000 F7200000 SDR/DDR SDRAM Control Reg   -
 * 73000000 F7300000 Static Memory Control Reg   -
 * 74000000 F7400000 IDE Control Reg             -
 * 76000000 F7600000 MISC Reg                    MISC Reg
 * 77000000 F7700000 Power Management Reg        Power Management Reg
 * 78000000 F7800000 UART0 Reg                   UART0 Reg
 * 78800000 F7880000 UART1 Reg                   -
 * 79000000 F7900000 Timer Reg                   Timer Reg
 * 7A000000 F7A00000 WatchDog Timer Reg          WatchDog Timer Reg
 * 7B000000 F7B00000 RTC Reg                     RTC Reg
 * 7C000000 F7C00000 GPIOA Reg                   GPIOA Reg
 * 7C800000 F7C80000 GPIOB Reg                   GPIOB Reg
 * 7D000000 F7D00000 -                           Interrupt Control Reg
 * 80000000 F8000000 -                           PCMCIA Control Reg
 * 90000000 F9000000 -                           PCMCIA Attribute Memory
 * 94000000 F9400000 -                           PCMCIA Common Memory
 * 98000000 F9800000 -                           PCMCIA I/O Space
 * A0000000 FA000000 PCI Config Data Reg         PCI Config Data Reg
 * A4000000 FA400000 PCI Config Address Reg      PCI Config Address Reg
 * A8000000 FA800000 PCI I/O Space               PCI I/O Space
 * B0000000 FB000000 PCI Memory Space            PCI Memory Space
 * C0000000 FC000000 USB1.1 Config Reg           USB1.1 Configuration Reg
 * C4000000 FC400000 USB1.1 Operation Reg        USB1.1 Operation Reg
 * C8000000 FC800000 USB2.0 Config Reg           USB2.0 Configuration Reg
 * CC000000 FCC00000 USB2.0 Operation Reg        USB2.0 Operation Reg
 * D0000000 FD000000 USB 1.1/2.0 Device Reg      -
 * FFFFF000 FFFFFF00 Vector Interrupt Control    -
 */

#define STAR_PCLK			43750000	/* PCLK=43.75MHz */
#define STAR_SDRAM_MEMORY	0x20000000	/* main memory (physical) */

/*
 * Physical memory 0x10000000-0xFFFFFFFF are mapped to Virtual memory 0xFnnnnnnn.
 * struct pmap_devmap table is in evbarm/star/star_machdep.c
 */
#define STAR_IOADDR_VBASE		0xF0000000
#define STAR_IOADDR_P2V(paddr)		(((((paddr) >> 4) & 0x0ff80000) + ((paddr) & 0x0007ffff)) + STAR_IOADDR_VBASE)
#define STAR_IOADDR_V2P(vaddr)		(((((vaddr) << 4) & 0xff800000) + ((vaddr) & 0x0007ffff)))
#define STAR_IOADDR_V2P_FFFF(vaddr)	(((((vaddr) << 4) & 0xff800000) + ((vaddr) & 0x007fffff)))

#define STAR_IOADDR_SIZE		0x00080000	/* max I/O size */

/* read/write on virtual addr */
#define STAR_REG_READ32(addr)		(*(volatile uint32_t *)(addr))
#define STAR_REG_WRITE32(addr, v)	(*(volatile uint32_t *)(addr) = (v))
#define STAR_REG_READ16(addr)		(*(volatile uint16_t *)(addr))
#define STAR_REG_WRITE16(addr, v)	(*(volatile uint16_t *)(addr) = (v))
#define STAR_REG_READ8(addr)		(*(volatile uint8_t *)(addr))
#define STAR_REG_WRITE8(addr, v)	(*(volatile uint8_t *)(addr) = (v))


/*
 * STR8100, STR9100 SoC Devices
 */
#define STR9100_FLASH_SRAM_MEMORY		STAR_IOADDR_P2V(0x10000000)	/*   ---  ,  STR9100 */
#define STR8100_FLASH_SRAM_MEMORY_BANK0		STAR_IOADDR_P2V(0x10000000)	/* STR8100,    ---   */
#define STR8100_FLASH_SRAM_MEMORY_BANK1		STAR_IOADDR_P2V(0x11000000)	/* STR8100,    ---   */
#define STR8100_FLASH_SRAM_MEMORY_BANK2		STAR_IOADDR_P2V(0x12000000)	/* STR8100,    ---   */
#define STR8100_FLASH_SRAM_MEMORY_BANK3		STAR_IOADDR_P2V(0x13000000)	/* STR8100,    ---   */
#define STR8100_IDE_DEVICE_REGISTER_SPACE	STAR_IOADDR_P2V(0x18000000)	/* STR8100,    ---   */
#define STR8100_SPI_SERIAL_FLASH_MEMORY		STAR_IOADDR_P2V(0x30000000)	/* STR8100,    ---   */
#define STR9100_STATIC_MEMORY_CONTROL_REGISTER	STAR_IOADDR_P2V(0x30000000)	/*   ---  ,  STR9100 */
#define STR9100_SDRAM_CONTROL_REGISTER		STAR_IOADDR_P2V(0x40000000)	/*   ---  ,  STR9100 */
#define STRx100_GENERIC_DMA_REGISTER		STAR_IOADDR_P2V(0x60000000)	/* STR8100,  STR9100 */
#define STR8100_NIC_REGISTER			STAR_IOADDR_P2V(0x70000000)	/* STR8100,    ---   */
#define STR9100_SWITCH_AND_HNAT_REGISTER	STAR_IOADDR_P2V(0x70000000)	/*   ---  ,  STR9100 */
#define STR8100_SPI_PCM_TWI_I2S_REGISTER	STAR_IOADDR_P2V(0x71000000)	/* STR8100,    ---   */
#define STR8100_SDRAM_CONTROL_REGISTER		STAR_IOADDR_P2V(0x72000000)	/* STR8100,    ---   */
#define STR8100_STATIC_MEMORY_CONTROL_REGISTER	STAR_IOADDR_P2V(0x73000000)	/* STR8100,    ---   */
#define STR8100_IDE_CONTROL_REGISTER		STAR_IOADDR_P2V(0x74000000)	/* STR8100,    ---   */
#define STRx100_MISC_REGISTER			STAR_IOADDR_P2V(0x76000000)	/* STR8100,  STR9100 */
#define STRx100_POWER_MANAGEMENT_REGISTER	STAR_IOADDR_P2V(0x77000000)	/* STR8100,  STR9100 */
#define STRx100_UART0_REGISTER			STAR_IOADDR_P2V(0x78000000)	/* STR8100,  STR9100 */
#define STR8100_UART1_REGISTER			STAR_IOADDR_P2V(0x78800000)	/* STR8100,    ---   */
#define STRx100_TIMER_REGISTER			STAR_IOADDR_P2V(0x79000000)	/* STR8100,  STR9100 */
#define STRx100_WDT_REGISTER			STAR_IOADDR_P2V(0x7A000000)	/* STR8100,  STR9100 */
#define STRx100_RTC_REGISTER			STAR_IOADDR_P2V(0x7B000000)	/* STR8100,  STR9100 */
#define STRx100_GPIOA_REGISTER			STAR_IOADDR_P2V(0x7C000000)	/* STR8100,  STR9100 */
#define STR8100_GPIOB_REGISTER			STAR_IOADDR_P2V(0x7C800000)	/* STR8100,    ---   */
#define STR9100_INTERRUPT_CONTROL_REGISTER	STAR_IOADDR_P2V(0x7D000000)	/*   ---  ,  STR9100 */
#define STR9100_PCMCIA_CONTROL_REGISTER		STAR_IOADDR_P2V(0x80000000)	/*   ---  ,  STR9100 */
#define STR9100_PCMCIA_ATTRIBUTE_MEMORY		STAR_IOADDR_P2V(0x90000000)	/*   ---  ,  STR9100 */
#define STR9100_PCMCIA_COMMON_MEMORY		STAR_IOADDR_P2V(0x94000000)	/*   ---  ,  STR9100 */
#define STR9100_PCMCIA_IO_SPACE			STAR_IOADDR_P2V(0x98000000)	/*   ---  ,  STR9100 */
#define STRx100_PCI_CONFIGURATION_DATA_REGISTER	STAR_IOADDR_P2V(0xA0000000)	/* STR8100,  STR9100 */
#define STRx100_PCI_CONFIGURATION_ADDR_REGISTER	STAR_IOADDR_P2V(0xA4000000)	/* STR8100,  STR9100 */
#define STRx100_PCI_IO_SPACE			STAR_IOADDR_P2V(0xA8000000)	/* STR8100,  STR9100 */
#define STRx100_PCI_MEMORY_SPACE		STAR_IOADDR_P2V(0xB0000000)	/* STR8100,  STR9100 */
#define STRx100_USB11_CONFIGURATION_REGISTER	STAR_IOADDR_P2V(0xC0000000)	/* STR8100,  STR9100 */
#define STRx100_USB11_OPERATION_REGISTER	STAR_IOADDR_P2V(0xC4000000)	/* STR8100,  STR9100 */
#define STRx100_USB20_CONFIGURATION_REGISTER	STAR_IOADDR_P2V(0xC8000000)	/* STR8100,  STR9100 */
#define STRx100_USB20_OPERATION_REGISTER	STAR_IOADDR_P2V(0xCC000000)	/* STR8100,  STR9100 */
#define STR8100_USB11_20_DEVICE_REGISTER	STAR_IOADDR_P2V(0xD0000000)	/* STR8100,    ---   */
#define STR8100_INTERRUPT_CONTROL_REGISTER	STAR_IOADDR_P2V(0xFFFFF000)	/* STR8100,    ---   */


/*
 * Peripheral Interrupts Source Mapping
 */
#define STAR_IRQ_TIMER1			0	/* STR8100,  STR9100 */
#define STAR_IRQ_TIMER2			1	/* STR8100,  STR9100 */
#define STAR_IRQ_CPUFREQ_CLKPWR		2	/* STR8100,  STR9100 */
#define STAR_IRQ_WDOG			3	/* STR8100,  STR9100 */
#define STAR_IRQ_GPIO			4	/* STR8100,  STR9100 */
#define STAR_IRQ_PCIEXT0		5	/* STR8100,  STR9100 */
#define STAR_IRQ_PCIEXT1		6	/* STR8100,  STR9100 */
#define STAR_IRQ_PCIEXT2		7	/* STR8100,  STR9100 */
#define STAR_IRQ_PCIBRIDGE		8	/* STR8100,  STR9100 */
#define STAR_IRQ_UART0			9	/* STR8100,    ---   */
#define STAR_IRQ_UART1			10	/* STR8100,  STR9100 */
#define STAR_IRQ_DMA			11	/* STR8100,  STR9100 */
#define STAR_IRQ_DMAERR			12	/* STR8100,  STR9100 */
#define STAR_IRQ_PCMCIA			13	/*   ---  ,  STR9100 */
#define STAR_IRQ_RTC			14	/* STR8100,  STR9100 */
#define STAR_IRQ_PCM_EXTINT		15	/* STR8100 , STR9100 */
#define STAR_IRQ_USB			16	/* STR8100,    ---   */
#define STAR_IRQ_IDE			17	/* STR8100,    ---   */
#define STAR_IRQ_NIC_MIB		18	/* STR8100,  STR9100 */
#define STAR_IRQ_NIC_TX			19	/* STR8100,  STR9100 */
#define STAR_IRQ_NIC_RX			20	/* STR8100,  STR9100 */
#define STAR_IRQ_NIC_EMPTY		21	/* STR8100,  STR9100 */
#define STAR_IRQ_NIC_FULL		22	/* STR8100,  STR9100 */
#define STAR_IRQ_USB11			23	/* STR8100,  STR9100 */
#define STAR_IRQ_USB20			24	/* STR8100,  STR9100 */
#define STAR_IRQ_I2S			25	/* STR8100,    ---   */
#define STAR_IRQ_SPI			26	/* STR8100,    ---   */
#define STAR_IRQ_TWI			27	/* STR8100,    ---   */
#define STAR_IRQ_USB_VBUS		28	/* STR8100,    ---   */
#define STAR_IRQ_EXT_GPIOA0		29	/* STR8100,    ---   */
#define STAR_IRQ_EXT_GPIOA1		30	/* STR8100,    ---   */
#define STAR_IRQ_HSDMA			31	/* STR8100,    ---   */

#define STAR_IRQ_START			0
#define STAR_NIRQ			32



#define STAR_UART_SIZE	0x20
#define STAR_UART_FREQ	24000000L	/* 24MHz (UART PSR=1) */


/*
 * STR8100 - DDR/SDR SDRAM Controller (P:0x72000000, V:0xF7200000)
 */
#define EQUULEUS_SDRAMCTRL_MEM_CFG_REG		(STR8100_SDRAM_CONTROL_REGISTER + 0x00)
# define EQUULEUS_SDRAMCTRL_MEM_CFG_DDR_EN	0x02000000
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMWT_MASK	0x00000030
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMW_x4	0x00000000
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMW_x8	0x00000010
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMW_x16	0x00000020
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_MASK	0x00000007
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_128Mb	0x00000000
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_256Mb	0x00000001
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_512Mb	0x00000002
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_1Gb	0x00000003
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_16Mb	0x00000004
# define EQUULEUS_SDRAMCTRL_MEM_CFG_MEMSZ_64Mb	0x00000005

#define EQUULEUS_SDRAMCTRL_DRAM_CFG_REG		(STR8100_SDRAM_CONTROL_REGISTER + 0x04)
#define EQUULEUS_SDRAMCTRL_PWON_INIT_CTRL_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x08)
#define EQUULEUS_SDRAMCTRL_DRAM_TIMING0_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x10)
#define EQUULEUS_SDRAMCTRL_DRAM_TIMING1_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x14)
#define EQUULEUS_SDRAMCTRL_DRAM_TIMING2_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x18)
#define EQUULEUS_SDRAMCTRL_PREREAD_TMO_DIS_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x1c)
#define EQUULEUS_SDRAMCTRL_PREREAD_EN_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x20)
#define EQUULEUS_SDRAMCTRL_PREREAD_TMO0_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x24)
#define EQUULEUS_SDRAMCTRL_PREREAD_TMO1_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x28)
#define EQUULEUS_SDRAMCTRL_DDQ_OUT_DLY_CTRL_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x30)
#define EQUULEUS_SDRAMCTRL_DDQ_IN_DLY_CTRL_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x34)
#define EQUULEUS_SDRAMCTRL_PAD_PWR_DOWN_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x3c)

/*
 * STR9100 - DDR/SDR SDRAM Controller (P:0x40000000, V:0xF4000000)
 */
#define ORION_SDRAMCTRL_DDRC_TIMING0_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x00)
#define ORION_SDRAMCTRL_DDRC_TIMING1_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x04)
#define ORION_SDRAMCTRL_DDRC_CFG_REG		(STR9100_SDRAM_CONTROL_REGISTER + 0x08)
#define ORION_SDRAMCTRL_BANK_CFG_REG		(STR9100_SDRAM_CONTROL_REGISTER + 0x0c)
# define ORION_SDRAMCTRL_BANK_CFG_BNK_EN	0x00000100
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DDW_MASK	0x000000c0
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DDW_x4	0x00000000
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DDW_x8	0x00000040
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DDW_x16	0x00000080
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DSZ_MASK	0x00000030
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DSZ_64Mb	0x00000000
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DSZ_128Mb	0x00000010
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DSZ_256Mb	0x00000020
# define ORION_SDRAMCTRL_BANK_CFG_BNK_DSZ_512Mb	0x00000030
# define ORION_SDRAMCTRL_BANK_CFG_BNK_MBW	0x00000001
#define ORION_SDRAMCTRL_PAD_PWR_DOWN_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x10)
#define ORION_SDRAMCTRL_DDQ_OUT_DELAY_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x14)
#define ORION_SDRAMCTRL_DDQ_IN_DELAY_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x18)
#define ORION_SDRAMCTRL_PREREAD_EN_REG		(STR9100_SDRAM_CONTROL_REGISTER + 0x1c)
#define ORION_SDRAMCTRL_GDMA_PREREAD_TMO_REG	(STR8100_SDRAM_CONTROL_REGISTER + 0x20)
#define ORION_SDRAMCTRL_GSW_PREREAD_TMO_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x24)
#define ORION_SDRAMCTRL_USB20_PREREAD_TMO_REG	(STR9100_SDRAM_CONTROL_REGISTER + 0x28)


/*
 * STRx100 - Miscellaneous Registers (P:0x76000000, V:0xF7600000)
 */
#define STAR_MISC_REMAP			(STRx100_MISC_REGISTER + 0x0000)
#define STAR_MISC_CHIP_CONFIG		(STRx100_MISC_REGISTER + 0x0004)	/* STR8100 only */
#define STAR_MISC_PCI_CONTROL		(STRx100_MISC_REGISTER + 0x0010)	/* STR8100 only */
#define STAR_MISC_PCI_BROKEN_STATUS	(STRx100_MISC_REGISTER + 0x0014)	/* STR8100 only */
#define STAR_MISC_PCI_ID_CAPABILITY	(STRx100_MISC_REGISTER + 0x0018)
#define STAR_MISC_PCI_CTRL		(STRx100_MISC_REGISTER + 0x001c)	/* STR9100 only */
#define STAR_MISC_GPIO_A_PIN_REG	(STRx100_MISC_REGISTER + 0x0020)
#define STAR_MISC_GPIO_B_PIN_REG	(STRx100_MISC_REGISTER + 0x0020)
#define STAR_MISC_PCI_TRANSCTRL		(STRx100_MISC_REGISTER + 0x0034)	/* STR9100 only */


/*
 * STRx100 - Clock and Power Management (P:0x77000000, V:0xF7700000)
 */
#define STAR_CLKPWR_CLKGATE0_REG	(STRx100_POWER_MANAGEMENT_REGISTER + 0x0000)
# define STAR_CLKPWR_CLKGATE0_PCI		0x40000000
# define STAR_CLKPWR_CLKGATE0_HCLK_PCH		0x10000000
# define STAR_CLKPWR_CLKGATE0_HCLK_USBH		0x01000000
# define STAR_CLKPWR_CLKGATE0_MAC_CLK		0x00800000
# define STAR_CLKPWR_CLKGATE0_MDC_CLK		0x00400000
# define STAR_CLKPWR_CLKGATE0_PCLK_NIC		0x00200000
# define STAR_CLKPWR_CLKGATE0_HCLK_NIC		0x00100000
# define STAR_CLKPWR_CLKGATE0_HCLK_GDMA		0x00010000
# define STAR_CLKPWR_CLKGATE0_HCLK_VIC		0x00001000
# define STAR_CLKPWR_CLKGATE0_PCLK_IDE		0x00000200
# define STAR_CLKPWR_CLKGATE0_HCLK_IDE		0x00000100
# define STAR_CLKPWR_CLKGATE0_PCLK_SMC		0x00000020
# define STAR_CLKPWR_CLKGATE0_HCLK_SMC		0x00000010
# define STAR_CLKPWR_CLKGATE0_PCLK_SDMC		0x00000002
# define STAR_CLKPWR_CLKGATE0_HCLK_SDMC		0x00000001
#define STAR_CLKPWR_CLKGATE1_REG	(STRx100_POWER_MANAGEMENT_REGISTER + 0x0004)
# define STAR_CLKPWR_CLKGATE1_HCLK_HSDMA	0x20000000
# define STAR_CLKPWR_CLKGATE1_HCLK_USBD		0x10000000
# define STAR_CLKPWR_CLKGATE1_PCLK_GPIO		0x02000000
# define STAR_CLKPWR_CLKGATE1_PCLK_RTC		0x00800000
# define STAR_CLKPWR_CLKGATE1_PCLK_WDT		0x00200000
# define STAR_CLKPWR_CLKGATE1_PCLK_TIMER	0x00020000
# define STAR_CLKPWR_CLKGATE1_PCLK_UART1	0x00002000
# define STAR_CLKPWR_CLKGATE1_PCLK_UART0	0x00001000
# define STAR_CLKPWR_CLKGATE1_I2S_CLK		0x00000400
# define STAR_CLKPWR_CLKGATE1_PCM_CLK		0x00000040
# define STAR_CLKPWR_CLKGATE1_PCLK_P2S		0x00000002
# define STAR_CLKPWR_CLKGATE1_HCLK_SPI		0x00000001
#define STAR_CLKPWR_SOFTRST_REG		(STRx100_POWER_MANAGEMENT_REGISTER + 0x0008)
# define STAR_CLKPWR_SOFTRST_HSDMA		0x00010000
# define STAR_CLKPWR_SOFTRST_FE_PHY		0x00008000
# define STAR_CLKPWR_SOFTRST_USBD		0x00004000
# define STAR_CLKPWR_SOFTRST_GPIO		0x00002000
# define STAR_CLKPWR_SOFTRST_WDT		0x00001000
# define STAR_CLKPWR_SOFTRST_TIMER		0x00000800
# define STAR_CLKPWR_SOFTRST_UART1		0x00000400
# define STAR_CLKPWR_SOFTRST_UART0		0x00000200
# define STAR_CLKPWR_SOFTRST_P2S		0x00000100
# define STAR_CLKPWR_SOFTRST_PCI		0x00000080
# define STAR_CLKPWR_SOFTRST_USBH		0x00000040
# define STAR_CLKPWR_SOFTRST_NIC		0x00000020
# define STAR_CLKPWR_SOFTRST_GDMA		0x00000010
# define STAR_CLKPWR_SOFTRST_VIC		0x00000008
# define STAR_CLKPWR_SOFTRST_IDE		0x00000004
# define STAR_CLKPWR_SOFTRST_SMC		0x00000002
# define STAR_CLKPWR_SOFTRST_GLOBAL		0x00000001
#define STAR_CLKPWR_CLKCTRL_REG		(STRx100_POWER_MANAGEMENT_REGISTER + 0x000c)
# define STAR_CLKPWR_CLKCTRL_MDC_DIV(n)		(((n) & 3) << 14)
# define STAR_CLKPWR_CLKCTRL_I2S_SEL(n)		(((n) & 3) << 12)
# define STAR_CLKPWR_CLKCTRL_PCI_DIV(n)		(((n) & 3) << 10)
# define STAR_CLKPWR_CLKCTRL_PCLK_DIV(n)	(((n) & 3) << 8)
# define STAR_CLKPWR_CLKCTRL_NICCLK_SEL		0x00000080
# define STAR_CLKPWR_CLKCTRL_RTC_SEL		0x00000040
# define STAR_CLKPWR_CLKCTRL_HCLK_DIV(n)	(((n) & 3) << 4)
# define STAR_CLKPWR_CLKCTRL_FCLK_DIV(n)	(((n) & 3) << 2)
# define STAR_CLKPWR_CLKCTRL_CPU_PLL_SEL(n)	((n) & 3)
# define STAR_CLKPWR_CLKCTRL_CPU_PLL_SEL_MASK	0x00000003
#define STAR_CLKPWR_PLLCTRL_REG		(STRx100_POWER_MANAGEMENT_REGISTER + 0x0010)
# define STAR_CLKPWR_PLLCTRL_SYSTEM_XTAL_PWD	0x00000080
# define STAR_CLKPWR_PLLCTRL_PLLx7_PWD		0x00000040
# define STAR_CLKPWR_PLLCTRL_PLLx2250_PWD	0x00000020
# define STAR_CLKPWR_PLLCTRL_USBD_PHY_PWD	0x00000010
# define STAR_CLKPWR_PLLCTRL_USBH_PHY_PWD	0x00000008
# define STAR_CLKPWR_PLLCTRL_PLLx3_PWD		0x00000004
# define STAR_CLKPWR_PLLCTRL_PLLx8_PWD		0x00000002
# define STAR_CLKPWR_PLLCTRL_PLLx5_PWD		0x00000001
#define STAR_CLKPWR_PADCTRL_REG		(STRx100_POWER_MANAGEMENT_REGISTER + 0x001c)
#define STAR_CLKPWR_PADCTRL_MII_NOT_BOUNDED	0x00000008
#define STAR_CLKPWR_PADCTRL_MII_SPEED		0x00000004
#define STAR_CLKPWR_PADCTRL_PCI_DRIVE_SEL(n)	((n) & 3)


/*
 * STRx100 - Timer Registers (P:0x79000000, V:0xF7900000)
 */
#define STAR_TIMER1_COUNTER		0x00000000	/* if up/down to 0, would be reloaded */
#define STAR_TIMER1_LOAD		0x00000004	/* if up/down to 0, reload this value */
#define STAR_TIMER1_MATCH1		0x00000008	/* Match1 interrupt when counter is equal to */
#define STAR_TIMER1_MATCH2		0x0000000c	/* Match2 interrupt when counter is equal to */
#define STAR_TIMER2_COUNTER		0x00000010	/* same as TIMER1 */
#define STAR_TIMER2_LOAD		0x00000014
#define STAR_TIMER2_MATCH1		0x00000018
#define STAR_TIMER2_MATCH2		0x0000001c
#define STAR_TIMER_CTRL			0x00000030
# define STAR_TIMER_CTRL_TM2_DECREMENT		0x00000400	/* RW: 0:Up, 1:Down */
# define STAR_TIMER_CTRL_TM1_DECREMENT		0x00000200	/* RW: 0:Up, 1:Down */
# define STAR_TIMER_CTRL_TM2OVERFLOWENABLE	0x00000020	/* RW: 0:Disable, 1:Enable */
# define STAR_TIMER_CTRL_TM2CLOCK_1KHZ		0x00000010	/* RW: 0:PCLK, 1:1KHz */
# define STAR_TIMER_CTRL_TM2ENABLE		0x00000008	/* RW: 0:Disable, 1:Enable */
# define STAR_TIMER_CTRL_TM1OVERFLOWENABLE	0x00000004	/* RW: 0:Disable, 1:Enable */
# define STAR_TIMER_CTRL_TM1CLOCK_1KHZ		0x00000002	/* RW: 0:PCLK, 1:1KHz */
# define STAR_TIMER_CTRL_TM1ENABLE		0x00000001	/* RW: 0:Disable, 1:Enable */
#define STAR_TIMER_INT_STATUS		0x00000034	/* RWC: 0:none: 1:active */
#define STAR_TIMER_INT_MASK		0x00000038	/* RW: 0:nonmask, 1:masked */
# define STAR_TIMER_INT_TM2OVERFLOW		0x00000020
# define STAR_TIMER_INT_TM2MATCH2		0x00000010
# define STAR_TIMER_INT_TM2MATCH1		0x00000008
# define STAR_TIMER_INT_TM1OVERFLOW		0x00000004
# define STAR_TIMER_INT_TM1MATCH2		0x00000002
# define STAR_TIMER_INT_TM1MATCH1		0x00000001
#define STAR_TIMER_FREERUN		0x00000040	/* Timer3 100KHz Free Running Counter [31:0] bit */
#define STAR_TIMER_FREERUN_CTRL		0x00000044
# define STAR_TIMER_FREERUN_TM3RUN		0000020000	/* RW: 0:stop, 1:run */
# define STAR_TIMER_FREERUN_TM3RESET		0x00010000	/* WCt */
# define STAR_TIMER_FREERUN_TM3HI		0x0000ffff	/* RO 100KHz Free Running Counter [47:32] bit */

#define STRx100_TIMER_REGSIZE	0x48	/* size of Timer Registes */


/*
 * STRx100 - RTC (P:0x7B000000, V:0xF7B00000)
 */
#define STAR_RTC_SEC			0x00000000
#define STAR_RTC_MIN			0x00000004
#define STAR_RTC_HOUR			0x00000008
#define STAR_RTC_DAYS			0x0000000c
#define STAR_RTC_ALRM_SEC		0x00000010
#define STAR_RTC_ALRM_MIN		0x00000014
#define STAR_RTC_ALRM_HOUR		0x00000018
#define STAR_RTC_RECORD			0x0000001c
#define STAR_RTC_CTRL			0x00000020
#define STAR_RTC_INTSTAT		0x00000034
#define STAR_RTC_REGSIZE		0x00000038


/*
 * STRx100 - GPIOA/GPIOB (P:0x7C000000, V:0xF7C00000)
 */
#define GPIOA_DATA_OUTPUT_REG			(STRx100_GPIOA_REGISTER + 0x0000)
#define GPIOA_DATA_INPUT_REG			(STRx100_GPIOA_REGISTER + 0x0004)

#define GPIOB_DATA_OUTPUT_REG			(STRx100_GPIOB_REGISTER + 0x0000)
#define GPIOB_DATA_INPUT_REG			(STRx100_GPIOB_REGISTER + 0x0000)



/*
 * STRx100 - USB1.1 and USB2.0 Configuration Register, Operation Register
 */
#define STAR_USB11_CONF_COMMAND		0x00000004
#define STAR_USB11_CONF_MODE_ENABLE	0x00000044
#define STAR_USB11_CONF_REGSIZE		0x48
#define STAR_USB11_OPERATION_REGSIZE	0x5c
#define STAR_USB20_CONF_COMMAND		0x00000004
#define STAR_USB20_CONF_MODE_ENABLE	0x00000040
#define STAR_USB20_CONF_REGSIZE		0x44
#define STAR_USB20_OPERATION_REGSIZE	0x6c


/*
 * STR8100 - Vector Interrupt Control Registers (P:0xFFFFF000, V:0xFFFFF000)
 */
#define EQUULEUS_INT_RAWSTATUS		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x000)	/* RO: 0:noactive, 1:active */
#define EQUULEUS_INT_CLEAR		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x004)	/* WC: 0:noeffect, 1:clearactive */
#define EQUULEUS_INT_MASK		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x008)	/* RW: 0:unmasked, 1:masked */
#define EQUULEUS_INT_MASKCLEAR		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x00c)	/* WO: 0:noeffect, 1:clearmask */
#define EQUULEUS_INT_TRIGMODE		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x010)	/* RW: 0:LevelTrigger, 1:EdgeTrigger */
#define EQUULEUS_INT_TRIGLEVEL		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x014)	/* RW: 0:HighLevelTrigger, 1:LowLevelTrigger */
#define EQUULEUS_INT_FIQSEL		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x018)	/* RW: 0:IRQ, 1:FIQ */
#define EQUULEUS_INT_IRQSTATUS		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x01c)	/* RO: 0:Inactive, 1:Active */
#define EQUULEUS_INT_FIQSTATUS		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x020)	/* RO: 0:Inactive, 1:Active */
#define EQUULEUS_INT_SOFTINT		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x024)	/* RW: 0:Inactive, 1:Active(Enable) */
#define EQUULEUS_INT_SOFTCLEAR		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x028)	/* WO: 0:noeffect, 1:Disable */
#define EQUULEUS_INT_SOFTPRIOMASK	(STR8100_INTERRUPT_CONTROL_REGISTER + 0x02c)	/* RW: 0x00-0xFF */
#define EQUULEUS_INT_PWRINTSEL		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x034)	/* RW: 0:no wakeup intr, 1:selected wakeup intr */
#define EQUULEUS_INT_VECTORADDR(n)	(STR8100_INTERRUPT_CONTROL_REGISTER + 0x040 + (n) * 4)	/* n:0-31 */
#define EQUULEUS_INT_PRIORITY(n)	(STR8100_INTERRUPT_CONTROL_REGISTER + 0x0c0 + (n) * 4)	/* n:0-31, prio:0-7 */
#define EQUULEUS_INT_IRQVECTOR		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x140)	/* RW: address of current active ISR */
#define EQUULEUS_INT_VIC_EN		(STR8100_INTERRUPT_CONTROL_REGISTER + 0x144)	/* RW: 0:Disable VIC, 1:Enable VIC */


/*
 * STR9100 - Interrupt Controller (P:0x7D000000, V:0xF7D00000)
 */
#define ORION_INT_STATUS		(STR9100_INTERRUPT_CONTROL_REGISTER + 0x0000)	/* RO: IRQ bitmapped */
#define ORION_INT_MASK			(STR9100_INTERRUPT_CONTROL_REGISTER + 0x0004)	/* RW: IRQ bitmapped */
#define ORION_INT_CLEAR			(STR9100_INTERRUPT_CONTROL_REGISTER + 0x0008)	/* WO: IRQ bitmapped */
#define ORION_INT_TRIGMODE		(STR9100_INTERRUPT_CONTROL_REGISTER + 0x000c)	/* RW: 0:LevelTrigger, 1:EdgeTrigger */
#define ORION_INT_TRIGLEVEL		(STR9100_INTERRUPT_CONTROL_REGISTER + 0x0010)	/* RW: 0:HighLevelTrigger, 1:LowLevelTrigger */
#define ORION_INT_IRQSTATUS		(STR9100_INTERRUPT_CONTROL_REGISTER + 0x0014)	/* RO: 0:Inactive, 1:Active */
#define ORION_INT_FIQSEL		(STR9100_INTERRUPT_CONTROL_REGISTER + 0x0018)	/* RW: 0:IRQ, 1:FIQ */


#endif /* _STARREG_H_ */
